#### General

Node ID
  {$ ctrl.node.uuid | noValue $}
Chassis ID
  {$ ctrl.node.chassis_uuid | noValue $}
Created At
  {$ ctrl.node.created_at | date:'medium' | noValue $}
Extra
  {$ ctrl.node.extra | noValue $}

#### Ports

{$ 'Create port' | translate $} {$ 'Delete ports' | translate $}
| MAC Address | Extra | Actions
--- | --- | --- | ---
| {$ port.address $} | {$ port.address $} | {$ id $} {$ value $} |

#### Properties

{$ propertyName $}
  {$ propertyValue | noValue $}

#### Driver Info

Driver
  {$ ctrl.node.driver | noValue $}
SSH Port
  {$ ctrl.node.driver_info.ssh_port | noValue $}
SSH Username
  {$ ctrl.node.driver_info.ssh_username | noValue $}
Deploy Kernel
  {$ ctrl.node.driver_info.deploy_kernel | noValue $} {$ ctrl.node.driver_info.deploy_kernel | noValue $}
Deploy Ramdisk
  {$ ctrl.node.driver_info.deploy_ramdisk | noValue $} {$ ctrl.node.driver_info.deploy_ramdisk | noValue $}

{$ id $}
  {$ value $}

#### Instance Info

Instance Name
  {$ ctrl.node.instance_info.display_name | noValue $}
Ramdisk
  {$ ctrl.node.instance_info.ramdisk | noValue $}
Kernel
  {$ ctrl.node.instance_info.kernel | noValue $}

{$ id $}
  {$ value | noValue $}